-- About LCSearch.lua
-- Updated to use Chromium browser. Supports v. 9.2 and above
-- LCSearch.lua does a Library of Congress Catalog search for  for the LoanTitle or PhotoJournalTitle.
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.

local settings = {};
settings.AutoSearch = GetSetting("AutoSearch");

local interfaceMngr = nil;
local LCSearchForm = {};
LCSearchForm.Form = nil;
LCSearchForm.Browser = nil;
LCSearchForm.RibbonPage = nil;

require "Atlas.AtlasHelpers";

function Init()
	interfaceMngr = GetInterfaceManager();
	
	-- Create a form
	LCSearchForm.Form = interfaceMngr:CreateForm("LC Search", "Script");
	
	-- Add a browser
	LCSearchForm.Browser = LCSearchForm.Form:CreateBrowser("LC Search", "LC Search Browser", "LC Search", "Chromium");
	
	-- Hide the text label
	LCSearchForm.Browser.TextVisible = false;
	
	-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
	LCSearchForm.RibbonPage = LCSearchForm.Form:GetRibbonPage("LC Search");
	
	-- Create the search button
	LCSearchForm.RibbonPage:CreateButton("Search", GetClientImage("Search32"), "Search", "LC");
	
	-- After we add all of our buttons and form elements, we can show the form.
	LCSearchForm.Form:Show();
	
	-- Search when opened if autoSearch is true
	if settings.AutoSearch then
		Search();
	end
end

function Search()
	local searchText = nil;
	
	if GetFieldValue("Transaction", "RequestType") == "Loan" then
		searchText = GetFieldValue("Transaction", "LoanTitle");
    else
		searchText = GetFieldValue("Transaction", "PhotoJournalTitle");
    end
	
	LCSearchForm.Browser:Navigate("http://catalog.loc.gov/vwebv/search?searchArg=" .. AtlasHelpers.UrlEncode(searchText) .. "&searchCode=GKEY^*&searchType=0&recCount=25&sk=en_US");
end

